/*
  Java gfx-test framework

   Copyright (C) 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.image.AffineTransformOp;



import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.NONE)
@Zoom(1)
public class BitBltAffineIdentityTransformOp extends BitBltAffineTransformOp
{
    private static final AffineTransform IdentifyTransformation = new AffineTransform();

    private static final AffineTransformOp IdentifyTransformationOp1;
    private static final AffineTransformOp IdentifyTransformationOp2;
    private static final AffineTransformOp IdentifyTransformationOp3;

    private static final AffineTransformOp IdentifyTransformationOp4;
    private static final AffineTransformOp IdentifyTransformationOp5;
    private static final AffineTransformOp IdentifyTransformationOp6;

    private static final RenderingHints RenderingHintsNearestNeighbor;
    private static final RenderingHints RenderingHintsBilinear;
    private static final RenderingHints RenderingHintsBicubic;

    static {
        RenderingHintsNearestNeighbor = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR);
        RenderingHintsBilinear = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
        RenderingHintsBicubic = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);

        IdentifyTransformationOp1 = new AffineTransformOp(IdentifyTransformation, AffineTransformOp.TYPE_NEAREST_NEIGHBOR);
        IdentifyTransformationOp2 = new AffineTransformOp(IdentifyTransformation, AffineTransformOp.TYPE_BILINEAR);
        IdentifyTransformationOp3 = new AffineTransformOp(IdentifyTransformation, AffineTransformOp.TYPE_BICUBIC);

        IdentifyTransformationOp4 = new AffineTransformOp(IdentifyTransformation, RenderingHintsNearestNeighbor);
        IdentifyTransformationOp5 = new AffineTransformOp(IdentifyTransformation, RenderingHintsBilinear);
        IdentifyTransformationOp6 = new AffineTransformOp(IdentifyTransformation, RenderingHintsBicubic);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /** * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeCustomIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeCustom(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBPreIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGBIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp1(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp1);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp2(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp3(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp4(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp4);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp5(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp5);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGrayIdentifyTransformationOp6(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeUshortGray(image, graphics2d, IdentifyTransformationOp6);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltAffineIdentityTransformOp().runTestSuite(args);
    }

}
